@@ -1,11 +1,22 @@
 # SPDX-FileCopyrightText: 2022 James R. Barlow
 # SPDX-License-Identifier: MPL-2.0
 
+"""Content stream parsing."""
+
 from __future__ import annotations
 
 from typing import TYPE_CHECKING, Collection, List, Tuple, Union, cast
 
-from pikepdf import Object, ObjectType, Operator, Page, PdfError, _qpdf
+from pikepdf._core import (
+    ContentStreamInlineImage,
+    ContentStreamInstruction,
+    Object,
+    ObjectType,
+    Page,
+    PdfError,
+    _unparse_content_stream,
+)
+from pikepdf.objects import Operator
 
 if TYPE_CHECKING:
     from pikepdf.models.image import PdfInlineImage
@@ -14,9 +25,7 @@ if TYPE_CHECKING:
 _OldContentStreamOperands = Collection[Union[Object, 'PdfInlineImage']]
 _OldContentStreamInstructions = Tuple[_OldContentStreamOperands, Operator]
 
-ContentStreamInstructions = Union[
-    _qpdf.ContentStreamInstruction, _qpdf.ContentStreamInlineImage
-]
+ContentStreamInstructions = Union[ContentStreamInstruction, ContentStreamInlineImage]
 
 UnparseableContentStreamInstructions = Union[
     ContentStreamInstructions, _OldContentStreamInstructions
@@ -24,6 +33,8 @@ UnparseableContentStreamInstructions = Union[
 
 
 class PdfParsingError(Exception):
+    """Error when parsing a PDF content stream."""
+
     def __init__(self, message=None, line=None):
         if not message:
             message = f"Error encoding content stream at line {line}"
@@ -34,8 +45,7 @@ class PdfParsingError(Exception):
 def parse_content_stream(
     page_or_stream: Object | Page, operators: str = ''
 ) -> list[ContentStreamInstructions]:
-    """
-    Parse a PDF content stream into a sequence of instructions.
+    """Parse a PDF content stream into a sequence of instructions.
 
     A PDF content stream is list of instructions that describe where to render
     the text and graphics in a PDF. This is the starting point for analyzing
@@ -60,19 +70,20 @@ def parse_content_stream(
             all tokens are accepted.
 
     Example:
-
-        >>> with pikepdf.Pdf.open(input_pdf) as pdf:
-        >>>     page = pdf.pages[0]
-        >>>     for operands, command in parse_content_stream(page):
-        >>>         print(command)
+        >>> with pikepdf.Pdf.open("../tests/resources/pal-1bit-trivial.pdf") as pdf:
+        ...     page = pdf.pages[0]
+        ...     for operands, command in pikepdf.parse_content_stream(page):
+        ...         print(command)
+        q
+        cm
+        Do
+        Q
 
     .. versionchanged:: 3.0
         Returns a list of ``ContentStreamInstructions`` instead of a list
         of (operand, operator) tuples. The returned items are duck-type compatible
         with the previous returned items.
-
     """
-
     if not isinstance(page_or_stream, (Object, Page)):
         raise TypeError("stream must be a pikepdf.Object or pikepdf.Page")
 
@@ -110,7 +121,8 @@ def parse_content_stream(
 def unparse_content_stream(
     instructions: Collection[UnparseableContentStreamInstructions],
 ) -> bytes:
-    """
+    """Convert collection of instructions to bytes suitable for storing in PDF.
+
     Given a parsed list of instructions/operand-operators, convert to bytes suitable
     for embedding in a PDF. In PDF the operator always follows the operands.
 
@@ -127,9 +139,8 @@ def unparse_content_stream(
         ``ContentStreamInstruction``, ``ContentStreamInlineImage``, and the older
         operand-operator tuples from pikepdf 2.x.
     """
-
     try:
-        return _qpdf._unparse_content_stream(instructions)
+        return _unparse_content_stream(instructions)
     except (ValueError, TypeError, RuntimeError) as e:
         raise PdfParsingError(
             "While unparsing a content stream, an error occurred"
